@@ -18,6 +18,7 @@ class PostgresClient(DBAPIClient):
         database: str
             database to connect
     """
+
     def __init__(self, user, password, host, port, database):
         """Constructor method for this children class.
 
@@ -34,5 +35,5 @@ class PostgresClient(DBAPIClient):
         database: str
             database to connect
         """
-        db = f'//{user}:{password}@{host}:{port}/{database}'
-        super().__init__('postgresql', db)
+        db = f"//{user}:{password}@{host}:{port}/{database}"
+        super().__init__("postgresql", db)
