@@ -75,3 +75,28 @@ def stock_data_to_pd(jsons_list):
         dfs.append(stock_df)
     df = pd.concat(dfs, axis=0)
     return df
+
+
+def df_to_plot_format_df(df):
+    """Transforms pandas.DataFrame to plot format.
+
+    Attributes
+    ----------
+        df: pandas DataFrame
+            df with open, high, low and close in different columns
+
+
+    Returns
+    -------
+        df_plot: pandas.DataFrame
+            df with columns value and type.
+    """
+    dfs = []
+    for col in ["open", "high", "low", "close"]:
+        aux_df = df[["symbol", "date", col]]
+        aux_df.columns = ["symbol", "date", "value"]
+        aux_df["type"] = col
+        dfs.append(aux_df)
+
+    df_plot = pd.concat(dfs)
+    return df_plot
